@@ -20,16 +20,13 @@ pub enum Error {
     Other {
         /// It's a custom error message
         message: String,
-        /// It's an original error message (if present)
-        origin: String,
     },
 }
 
 impl Error {
-    pub(crate) fn unknown(message: impl Into<String>, err: impl Display) -> Error {
+    pub(crate) fn unknown(message: impl Display, err: impl Display) -> Error {
         Self::Other {
-            message: message.into(),
-            origin: err.to_string(),
+            message: format!("{}: {}", message, err),
         }
     }
 }
@@ -41,8 +38,8 @@ impl Display for Error {
             Error::CommandParsing => write!(f, "Can't parse a command string, please check it out"),
             Error::RegexParsing => write!(f, "Can't parse a regex expression"),
             Error::ExpectTimeout => write!(f, "Reached a timeout for expect type of command"),
-            Error::Other { message, origin } => write!(f, "An erorr {} while {} ", origin, message),
             Error::Eof => write!(f, "EOF was reached; the read may successed later"),
+            Error::Other { message } => write!(f, "An other error; {} ", message),
         }
     }
 }
