@@ -26,9 +26,30 @@ fn bash() {
     assert_eq!(p.wait().unwrap(), WaitStatus::Exited(p.pid(), 0));
 }
 
+#[cfg(not(feature = "async"))]
+#[test]
+fn bash_with_log() {
+    let mut p = spawn_bash()
+        .unwrap()
+        .upgrade_session(|s| s.with_log(std::io::stderr()))
+        .unwrap();
+
+    p.send_line("echo Hello World").unwrap();
+    let mut msg = String::new();
+    p.read_line(&mut msg).unwrap();
+    assert!(msg.ends_with("Hello World\r\n"));
+
+    thread::sleep(Duration::from_millis(300));
+    p.send_control(ControlCode::EOT).unwrap();
+
+    assert_eq!(p.wait().unwrap(), WaitStatus::Exited(p.pid(), 0));
+}
+
 #[cfg(feature = "async")]
 #[test]
 fn bash() {
+    use futures_lite::AsyncReadExt;
+
     futures_lite::future::block_on(async {
         let mut p = spawn_bash().await.unwrap();
 
@@ -46,25 +67,50 @@ fn bash() {
 
 #[cfg(feature = "async")]
 #[test]
-fn python() {
-    let mut p = spawn_python().unwrap();
+fn bash_with_log() {
+    use futures_lite::AsyncReadExt;
 
     futures_lite::future::block_on(async {
-        p.execute("print('Hello World')").await.unwrap();
+        let mut p = spawn_bash()
+            .await
+            .unwrap()
+            .upgrade_session(|s| s.with_log(std::io::stderr()))
+            .unwrap();
+
+        p.send_line("echo Hello World").await.unwrap();
         let mut msg = String::new();
         p.read_line(&mut msg).await.unwrap();
-        assert_eq!(msg, "Hello World\r\n");
+        assert!(msg.ends_with("Hello World\r\n"));
+
+        thread::sleep(Duration::from_millis(300));
+        p.send_control(ControlCode::EOT).await.unwrap();
+
+        assert_eq!(p.wait().unwrap(), WaitStatus::Exited(p.pid(), 0));
+    })
+}
+
+#[cfg(feature = "async")]
+#[test]
+fn python() {
+    futures_lite::future::block_on(async {
+        let mut p = spawn_python().await.unwrap();
+
+        let prompt = p.execute("print('Hello World')").await.unwrap();
+        assert_eq!(prompt, b"Hello World\r\n");
 
         thread::sleep(Duration::from_millis(300));
         p.send_control(ControlCode::EndOfText).await.unwrap();
         thread::sleep(Duration::from_millis(300));
 
-        let mut msg1 = String::new();
-        p.read_line(&mut msg1).await.unwrap();
-        let mut msg2 = String::new();
-        p.read_line(&mut msg2).await.unwrap();
-        thread::sleep(Duration::from_millis(300));
-        assert_eq!(msg1 + &msg2, ">>> \r\nKeyboardInterrupt\r\n");
+        let mut msg = String::new();
+        p.read_line(&mut msg).await.unwrap();
+        assert_eq!(msg, "\r\n");
+
+        let mut msg = String::new();
+        p.read_line(&mut msg).await.unwrap();
+        assert_eq!(msg, "KeyboardInterrupt\r\n");
+
+        p.expect_prompt().await.unwrap();
 
         p.send_control(ControlCode::EndOfTransmission)
             .await
@@ -79,10 +125,8 @@ fn python() {
 fn python() {
     let mut p = spawn_python().unwrap();
 
-    p.execute("print('Hello World')").unwrap();
-    let mut msg = String::new();
-    p.read_line(&mut msg).unwrap();
-    assert_eq!(msg, "Hello World\r\n");
+    let prompt = p.execute("print('Hello World')").unwrap();
+    assert_eq!(prompt, b"Hello World\r\n");
 
     thread::sleep(Duration::from_millis(300));
     p.send_control(ControlCode::EndOfText).unwrap();
@@ -90,8 +134,13 @@ fn python() {
 
     let mut msg = String::new();
     p.read_line(&mut msg).unwrap();
+    assert_eq!(msg, "\r\n");
+
+    let mut msg = String::new();
     p.read_line(&mut msg).unwrap();
-    assert_eq!(msg, ">>> \r\nKeyboardInterrupt\r\n");
+    assert_eq!(msg, "KeyboardInterrupt\r\n");
+
+    p.expect_prompt().unwrap();
 
     p.send_control(ControlCode::EndOfTransmission).unwrap();
 
